@@ -30,6 +30,9 @@
 #define DISPLAY_NAME                "display-name"
 #define DISPLAY_SCALE               "display-scale"
 #define CAPS_LOCK_INDICATOR         "caps-lock-indicator"
+#ifdef HAVE_LIBNOTIFY
+#define SHOW_NOTIFICATIONS          "show-notifications"
+#endif
 #define DISPLAY_TOOLTIP_ICON        "display-tooltip-icon"
 #define GROUP_POLICY                "group-policy"
 
